@@ -10,6 +10,8 @@ codemirror <- getOption("prettify.codemirror")
 
 tabSize <- getOption("prettify.tabSize")
 
+language <- getOption("prettify.language")
+
 
 shinyUI(miniPage(
 
@@ -49,6 +51,11 @@ shinyUI(miniPage(
         tags$script(src = "autoFormatRange.js"),
         tags$link(rel = "stylesheet", href = "prettify.css")
       )
+    }else if(language == "sql"){
+      tagList(
+        tags$script(src = "sql-formatter/sql-formatter.min.js"),
+        tags$script(src = "prettify.js")
+      )
     }else{
       tagList(
         tags$script(src = "prettier/standalone.js"),
